@@ -1,12 +1,11 @@
-import codecs
 from pathlib import Path
-from typing import Type, Dict, Any, Generator, Optional
+from typing import Type, Dict, Any, Generator, Optional, Union
 import pandas as pd
 from fastapi import Query
 from progress.bar import Bar
-from pydantic import Field, BaseModel
+from pydantic import BaseModel
 from pydantic.dataclasses import dataclass
-from pyimporters_plugins.base import KnowledgeParserOptions, KnowledgeParserBase, Term
+from pyimporters_plugins.base import KnowledgeParserBase, Term
 
 from pyimporters_csv.text import file_len, TXTOptions
 
@@ -33,8 +32,8 @@ class CSVOptions(TXTOptions):
 CSVOptionsModel = CSVOptions.__pydantic_model__
 
 class CSVKnowledgeParser(KnowledgeParserBase):
-    def parse(self, source : Path, options : Dict[str,Any], bar : Bar) -> Generator[Term, None, None]:
-        options = CSVOptionsModel(**options)
+    def parse(self, source: Path, options: Union[BaseModel, Dict[str, Any]], bar: Bar) -> Generator[Term, None, None]:
+        options = CSVOptionsModel(**options) if isinstance(options, dict) else options
         bar.max = file_len(source)
         bar.start()
         lines = pd.read_csv(source,
