@@ -1,13 +1,12 @@
-import codecs
 from pathlib import Path
-from typing import Type, Dict, Any, Generator
-import pandas as pd
+from typing import Type, Dict, Any, Generator, Union
 from fastapi import Query
 from progress.bar import Bar
-from pydantic import Field, BaseModel
+from pydantic import BaseModel
 from pydantic.dataclasses import dataclass
 from pyimporters_plugins.base import KnowledgeParserOptions, KnowledgeParserBase, Term
 
+
 @dataclass
 class TXTOptions(KnowledgeParserOptions):
     """
@@ -18,8 +17,8 @@ class TXTOptions(KnowledgeParserOptions):
 TXTOptionsModel = TXTOptions.__pydantic_model__
 
 class TXTKnowledgeParser(KnowledgeParserBase):
-    def parse(self, source : Path, options : Dict[str,Any], bar : Bar) -> Generator[Term, None, None]:
-        options = TXTOptions(**options)
+    def parse(self, source: Path, options: Union[BaseModel, Dict[str, Any]], bar: Bar) -> Generator[Term, None, None]:
+        options = TXTOptionsModel(**options) if isinstance(options, dict) else options
         bar.max = file_len(source)
         bar.start()
         with source.open("r", encoding=options.encoding) as fin:
